#
# spec file for package maliit-framework
#
# Copyright (c) 2022 SUSE Software Solutions Germany GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libname_base libmaliit
%define _minsover 3.0
%define _sover 2
%define _name framework

Name:           maliit-framework
Version:        2.3.0
Release:        1.10
License:        LGPL-2.1-only
Summary:        Maliit input method framework
Group:          System/GUI/Other
Url:            https://github.com/maliit/framework
Source0:        https://github.com/maliit/%{_name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE maliit-framework-2.3.0-fix-ut_mimserveroptions-test-case-with-GCC-12-ADL.patch ionic@ionic.de -- Fixes building the test cases with GCC 12+.
Patch0:         maliit-framework-2.3.0-fix-ut_mimserveroptions-test-case-with-GCC-12-ADL.patch
BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5WaylandClient)
BuildRequires:  cmake(Qt5XkbCommonSupport)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  doxygen
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qtwayland-private-headers-devel

%description
Maliit provides a flexible and cross-platform input method framework.
It has a plugin-based client-server architecture where applications
act as clients and communicate with the Maliit server via input
context plugins. The communication link currently uses D-Bus. Maliit
is an open source framework (LGPL 2) with open source plugins (BSD).
This package also provides plugin support.

%package        doc
Summary:        Maliit Framework documentation
Group:          Documentation/HTML
%description    doc
Provides doxygen documentation for the Maliit Framework.

%package     -n %{_libname_base}-devel
Summary:        Maliit Framework development packages
Group:          Development/Libraries/C and C++
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < %{version}
Requires:       %{_libname_base}-plugins%{_sover} = %{version}-%{release}
Requires:       %{_libname_base}-glib%{_sover} = %{version}-%{release}
%description -n %{_libname_base}-devel
Provides headers and CMake files built for the Maliit Framework.

%package     -n %{_libname_base}-plugins%{_sover}
Summary:        Maliit Framework plugins shared library
Group:          System/GUI/Other
Requires:       %{name}
Obsoletes:      %{_libname_base}0 < %{version}
%description -n %{_libname_base}-plugins%{_sover}
Provides the plugin-related shared libraries built for the Maliit
Framework.

%package     -n %{_libname_base}-glib%{_sover}
Summary:        Maliit Framework glib shared library
Group:          System/GUI/Other
Requires:       %{name}
Obsoletes:      %{_libname_base}0 < %{version}
%description -n %{_libname_base}-glib%{_sover}
Provides the glib-related shared libraries built for the Maliit
Framework.

%package        tests
Summary:        Maliit Framework tests
Group:          System/GUI/Other
%description    tests
Provides unit tests of the Maliit Framework.

%prep
%autosetup -p1 -n %{_name}-%{version}/

%build
%cmake  -Denable-dbus-activation=ON \
        -Denable-hwkeyboard=ON \
        -Denable-qt5-inputcontext=ON \
        -Denable-wayland=ON \
        -Denable-xcb=ON \
        -Denable-glib=ON \
        -Denable-tests=ON \
        -Denable-docs=ON \
        -Denable-examples=OFF \
        -Dinstall-tests=ON
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n %{_libname_base}-plugins%{_sover}
%ldconfig_scriptlets -n %{_libname_base}-glib%{_sover}

%files doc
%{_datadir}/doc/maliit-framework-doc/
%{_datadir}/doc/maliit-framework/

%files -n %{_libname_base}-devel
%{_includedir}/maliit-2
%{_libdir}/cmake/{MaliitGLib,MaliitPlugins}/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libmaliit-plugins.so
%{_libdir}/libmaliit-glib.so
%{_libdir}/qt5/mkspecs/features/*.prf

%files tests
%{_libdir}/maliit-framework-tests

%files -n %{_libname_base}-plugins%{_sover}
%{_libdir}/libmaliit-plugins.so.%{_sover}
%{_libdir}/libmaliit-plugins.so.%{_sover}.%{_minsover}

%files -n %{_libname_base}-glib%{_sover}
%{_libdir}/libmaliit-glib.so.%{_sover}
%{_libdir}/libmaliit-glib.so.%{_sover}.%{_minsover}

%files
%doc README.md
%license LICENSE.LGPL
%{_bindir}/maliit-server
%{_libdir}/qt5/plugins/platforminputcontexts/libmaliitplatforminputcontextplugin.so
%{_libdir}/qt5/plugins/wayland-shell-integration/libinputpanel-shell.so
%{_datadir}/dbus-1/services/org.maliit.server.service

%changelog
* Tue Jul 19 2022 Mihai Moldovan <ionic@ionic.de>
- Update to upstream version 2.3.0:
  * Re-show the keyboard on Wayland surrounding text changes
  * Use compose input plugin fallback only if key redirection is
    disabled
  * Remove leftover code from Qt 4 times
  * Enable installing unit tests again
  * Remove legacy unused Maemo-specific code
  * Use QLoggingCategory for logging
  * Fix application orientation angle back to clockwise
  * Add the Mir input panel window type flag
  * Use CMAKE_INSTALL_FULL_* paths in pkgconfig files
  * Remove the unused and unnecessary gtk3 wayland input context
    plugin
  * Remove unused and useless install target
- Misc. whitespace- or comment-only changes.
- Modernize spec file by leaving out definition of the BuildRoot:
  tag or usage of the %%defattr macro.
- Add maliit-framework-tests subpackage for packaging the
  provided unit tests.
- Remove deleted wayland-gtk wrapper.
- Add patch to fix building the test cases with GCC 12+.
- Rename libmaliit0 to libmaliit2 and, at the same time, split it
  up into libmaliit-plugins2 and libmaliit-glib2, since both
  libraries are independent from another.
- Rename maliit-framework-devel to libmaliit-devel.
- Add rpmlintrc to ignore warnings and errors we are aware of,
  but want to do on purpose (which is fine).
- Add Group: tags to packages.
- Rename dist file to %%{name}-%%{version}.tar.gz and add the usual
  GitHub fetching URL.
- Modify _service file to recompress to gz instead and set the
  correct file name. However, it turns out that this is really
  broken. Add a comment and fall back to manual fetching for the
  time being.
* Tue Feb 15 2022 Andrés B.S. <andresbs@opensuse.org>
- Changes for the version 2.2.0:
  * Fix sending of modifiers and keysyms on Wayland by @dobey in
    [#74].
  * Fix deprecation warnings by @dobey in #75.
  * Use text-input-unstable-v2 protocol for QtWayland clients by
    @dobey in #63.
  * Add CI with GH Actions and fix tests by @dobey in #80.
  * CI: Run apt-get update and dist-upgrade before installing
    things by @dobey in #81.
  * Run the CI on Debian Testing with wayland enabled by @dobey
    in #82.
  * Correctly handle building with XCB disabled by @dobey in #83.
  * cmake: Lower requirement to 3.5 to allow building on Ubuntu
    16.04 by @dobey in #84.
  * NEWS: Update for 2.2.0 release by @dobey in #87.
* Mon Dec 27 2021 Andrés B.S. <andresbs@opensuse.org>
- Add a missing build requirement, pkgconfig(wayland-protocols).
* Tue Nov  2 2021 Andrés B.S. <andresbs@opensuse.org>
- Changes for the version 2.1.1:
  * Fix a (README) build error. No actual code has been changed.
* Wed Sep 22 2021 Andrés B.S. <andresbs@opensuse.org>
- Changes for the version 2.1.0:
  * Add cmake option to build examples and do not build them by
  default
  * Fix search for qtwaylandscanner on 32-bit architectures
  * Show the panel as the keyboard interface is reset
  * Ensure orientation updates are always sent when valid
  * Only allow focus removal from input items
  * Clean up FindGIO.cmake to allow working with older cmake
  * Stop client crashing when QGuiApplication::focusObject is null
  * Load compose inputcontext plugin for physical keyboard
    handling
  * Update input method area when activation is lost
  * input_method_v1: Treat content_purpose_digits just like
    content_purpose_number
  * Update or remove outdated and broken links
- Removed patch 0000-examples-optional.patch
- Backport 0000-Fix_installing_README.patch to fix build errors.
* Wed Apr 21 2021 Andrés B.S. <andresbs@opensuse.org>
- Do not build tests/examples, through the patch
  0000-examples-optional.
* Fri Apr  2 2021 Andrés B.S. <andresbs@opensuse.org>
- A patch to build with GTK integration (X11) has been added.
* Fri Apr  2 2021 Markus S <kamikazow@opensuse.org>
- Version 2.0 has been released, no changelog is provided. This
  solves bsc#1184014.
* Thu Feb 11 2021 Andrés B.S. <andresbs@opensuse.org>
- Builds without GTK components
